@@ -12,25 +12,33 @@ from typing import Sequence
 import cv2
 
 from draugr.drawers.drawer import Drawer
+from draugr.opencv_utilities import WindowFlagEnum
+from draugr.opencv_utilities.windows.default import match_return_code
+from warg import drop_unused_kws, passes_kws_to
+
+__all__ = ["OpencvImageStream"]
 
 
 class OpencvImageStream(Drawer):
     """ """
 
+    @drop_unused_kws
+    @passes_kws_to(Drawer.__init__)
     def __init__(self, title: str = "", render: bool = True, **kwargs):
 
+        super().__init__(**kwargs)
         if not render:
             return
 
         self.window_id = title
-        cv2.namedWindow(self.window_id, cv2.WINDOW_NORMAL)
+        cv2.namedWindow(self.window_id, WindowFlagEnum.normal.value)
 
     def draw(self, data: Sequence):
         """
 
         :param data:
         :return:"""
-        if cv2.waitKey(1) == 27:  # esc to quit
+        if match_return_code(cv2.waitKey(1)):  # esc to quit
             cv2.destroyWindow(self.window_id)
             raise StopIteration
         else:
@@ -48,9 +56,7 @@ if __name__ == "__main__":
 
         with AsyncVideoStream() as vc:
             with OpencvImageStream() as s:
-                for i in progress_bar(
-                    frame_generator(vc, coder=None), auto_total_generator=False
-                ):
+                for i in progress_bar(frame_generator(vc), auto_total_generator=False):
                     s.draw(i)
 
     asdasf()
