@@ -5,9 +5,9 @@ __author__ = "Christian Heider Nielsen"
 __doc__ = r"""
 """
 
-import pathlib
+from pathlib import Path
 
-with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
 
 from .accumulation import *
