@@ -9,6 +9,9 @@ __doc__ = r"""
 
 __all__ = ["NoData", "IncompatiblePackageVersions"]
 
+import types
+from typing import Iterable, MutableMapping, Union
+
 
 class NoData(Exception):
     """ """
@@ -20,7 +23,9 @@ class NoData(Exception):
 class IncompatiblePackageVersions(Exception):
     """ """
 
-    def __init__(self, *packages, **versions):
+    def __init__(
+        self, *packages: Iterable[Union[str, object]], **versions: MutableMapping
+    ):
         str_o = ", "
         str_l = []
 
@@ -33,25 +38,37 @@ class IncompatiblePackageVersions(Exception):
                     s += f"NotSpecified"
                 s += ")"
                 str_l.append(s)
-            else:
+            elif isinstance(p, types.ModuleType):
                 str_l.append(f"{p.__name__, p.__version__}")
+        for vk, vv in versions.items():
+            if vk not in packages:
+                str_l.append(f"({vk},{vv})")
 
         Exception.__init__(self, f"Packages {str_o.join(str_l)} are not compatible")
 
 
 if __name__ == "__main__":
 
-    def main():
-        """ """
+    def main() -> None:
+        """
+        :rtype: None
+        """
         raise IncompatiblePackageVersions(
-            "numpy", "scipy", "Something", numpy="0.0.1", scipy="0.0.2"
+            "numpy",
+            "scipy",
+            "Something",
+            numpy="0.0.1",
+            scipy="0.0.2",
+            some_other_packge="0.5.0",
         )
 
-    def main2():
-        """ """
+    def main2() -> None:
+        """
+        :rtype: None
+        """
         import numpy
         import scipy
 
         raise IncompatiblePackageVersions(numpy, scipy)
 
-    main2()
+    main()
