@@ -7,37 +7,40 @@ __doc__ = r"""
            Created on 21/02/2020
            """
 
+from typing import Union
+
+import numpy
 import torch
 
 __all__ = ["standardise"]
 
+from warg import Number
+
 
 def minus_one_one_unnormalise(
-    x: torch.tensor, low: float = 0, high: float = 1
+    x: Union[Number, torch.Tensor, numpy.ndarray], low: float = 0, high: float = 1
 ) -> torch.tensor:
-    """
-  """
+    """ """
     act_k = (high - low) / 2.0
     act_b = (high + low) / 2.0
     return act_k * x + act_b
 
 
 def minus_one_one_normalise(
-    x: torch.tensor, low: float = 0, high: float = 1
+    x: Union[Number, torch.Tensor, numpy.ndarray], low: float = 0, high: float = 1
 ) -> torch.tensor:
-    """
-  """
+    """ """
     act_k_inv = 2.0 / (high - low)
     act_b = (high + low) / 2.0
     return act_k_inv * (x - act_b)
 
 
-def standardise(x: torch.tensor, eps: float = 1e-6) -> torch.tensor:
+def standardise(x: torch.Tensor, eps: float = 1e-6) -> torch.tensor:
     """
 
-  :param eps:
-  :param x:
-  :return:"""
+    :param eps:
+    :param x:
+    :return:"""
     x -= x.mean()
     x /= x.std() + eps
     return x
